summaryrefslogtreecommitdiffstats
path: root/src/video_core/renderer_opengl/gl_rasterizer.h
diff options
context:
space:
mode:
authorLioncash <mathew1800@gmail.com>2019-07-09 01:26:44 +0200
committerLioncash <mathew1800@gmail.com>2019-07-09 08:08:15 +0200
commitc04785c92882e789d48ab8a5f8dd3af23d91e5b7 (patch)
tree5a624d3a1673a8bebc6ec19e100d92e4b2645d90 /src/video_core/renderer_opengl/gl_rasterizer.h
parentMerge pull request #2674 from lioncash/reporter (diff)
downloadyuzu-c04785c92882e789d48ab8a5f8dd3af23d91e5b7.tar
yuzu-c04785c92882e789d48ab8a5f8dd3af23d91e5b7.tar.gz
yuzu-c04785c92882e789d48ab8a5f8dd3af23d91e5b7.tar.bz2
yuzu-c04785c92882e789d48ab8a5f8dd3af23d91e5b7.tar.lz
yuzu-c04785c92882e789d48ab8a5f8dd3af23d91e5b7.tar.xz
yuzu-c04785c92882e789d48ab8a5f8dd3af23d91e5b7.tar.zst
yuzu-c04785c92882e789d48ab8a5f8dd3af23d91e5b7.zip
Diffstat (limited to '')
-rw-r--r--src/video_core/renderer_opengl/gl_rasterizer.h16
1 files changed, 9 insertions, 7 deletions
diff --git a/src/video_core/renderer_opengl/gl_rasterizer.h b/src/video_core/renderer_opengl/gl_rasterizer.h
index bf67e3a70..d238c1257 100644
--- a/src/video_core/renderer_opengl/gl_rasterizer.h
+++ b/src/video_core/renderer_opengl/gl_rasterizer.h
@@ -98,17 +98,19 @@ private:
/**
* Configures the color and depth framebuffer states.
* @param must_reconfigure If true, tells the framebuffer to skip the cache and reconfigure
* again. Used by the texture cache to solve texception conflicts
* @param use_color_fb If true, configure color framebuffers.
* @param using_depth_fb If true, configure the depth/stencil framebuffer.
* @param preserve_contents If true, tries to preserve data from a previously used framebuffer.
* @param single_color_target Specifies if a single color buffer target should be used.
+ *
* @returns If depth (first) or stencil (second) are being stored in the bound zeta texture
- * (requires using_depth_fb to be true)
+ * (requires using_depth_fb to be true)
*/
std::pair<bool, bool> ConfigureFramebuffers(
- OpenGLState& current_state, bool use_color_fb = true, bool using_depth_fb = true,
+ OpenGLState& current_state, bool using_color_fb = true, bool using_depth_fb = true,
bool preserve_contents = true, std::optional<std::size_t> single_color_target = {});
/// Configures the current constbuffers to use for the draw command.
@@ -98,17 +98,19 @@ private:
/**
* Configures the color and depth framebuffer states.
- * @param must_reconfigure If true, tells the framebuffer to skip the cache and reconfigure
- * again. Used by the texture cache to solve texception conflicts
- * @param use_color_fb If true, configure color framebuffers.
- * @param using_depth_fb If true, configure the depth/stencil framebuffer.
- * @param preserve_contents If true, tries to preserve data from a previously used framebuffer.
+ *
+ * @param current_state The current OpenGL state.
+ * @param using_color_fb If true, configure color framebuffers.
+ * @param using_depth_fb If true, configure the depth/stencil framebuffer.
+ * @param preserve_contents If true, tries to preserve data from a previously used
+ * framebuffer.
* @param single_color_target Specifies if a single color buffer target should be used.